Page 128 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 128

Home

    Early in his life Chiang became a disciple of Dr. Sun
    Yat-sen (a Chinese physician and a Christian) and
    worked with him in his attempts to overthrow the corrupt
    Manchu dynasty and unify China under a constitutional
    republic. After training at a Chinese military academy,
    and at Japan's Military Staff College, Chiang rose rapidly
    in his military career under Sun Yat-sen.

    In 1923, Dr. Sun Yat-sen sent Chiang to study the
    Bolshevik system in the Soviet Union. Here Chiang
    received insight into the communist system that enabled
    him to prevent an early attempt by the Communists to
    take over the government of China. Because of his
    observations Chiang wrote, "I became more convinced
    than ever that Soviet political institutions were
    instruments of tyranny and terror. . . . nil

    Chiang's Christian conversion came about as a result
    of his marriage to Soong Mayling, the daughter of a
    prominent Chinese Methodist minister and Bible
    publisher. After careful study of the Bible, as he had
    promised Madame Soong that he would undertake,
    Chiang became a profound Christian for the rest of his
    life, regularly searching the Scriptures for guides to
    ruling China.

    In 1928, Chiang answered a call to become chairman
    of the Nationalist Party's Central Committee. From this

    elevated position he and Madame Chiang were to
    exercise tremendous influence upon their people
    throughout China. Realizing that China needed a moral
    regeneration, he and Madame Chiang began what they

    123

    Babylon's War Against God